@@ -1174,14 +1174,13 @@ css_parser_prepare_stylesheet (const gchar *str, gint len)
 			       str[pos] != '\n')
 				pos++;
 		}
-		if (buffer_size == buffer_size_max)
+		if (buffer_size == buffer_size_max - 1)
 			result = g_realloc (result, (buffer_size_max <<= 1));
 		
 		result[buffer_size++] = str[pos++];
 		
 	}
 
-	/* FIXME: This may not be secure */
 	result[buffer_size] = '\0';
 
 	return result;
