@@ -764,7 +764,9 @@ html_document_clear (HtmlDocument *document)
 		
 		top_node =  node->xmlnode;
 		node = dom_Node__get_nextSibling (node);
-		g_signal_emit (G_OBJECT (document), document_signals [NODE_REMOVED], 0, tmp_node);
+		if (G_OBJECT (document)->ref_count != 0)
+			/* Not called from html_document_finalize */
+			g_signal_emit (G_OBJECT (document), document_signals [NODE_REMOVED], 0, tmp_node);
 		dom_Node_removeChild (DOM_NODE (document->dom_document), tmp_node, NULL);
 		g_object_unref (tmp_node);
 	}
